@@ -1,3 +1,4 @@
+from xmlrpc.client import boolean
 import websockets
 import asyncio
 import json
@@ -15,7 +16,8 @@ class RPCClient(object):
                  port: int = 9090,
                  cb_connected: Callable[[], None] = None,
                  cb_disconnected: Callable[[], None] = None,
-                 loop: asyncio.BaseEventLoop = None):
+                 loop: asyncio.BaseEventLoop = None,
+                 is_ssl: boolean = False):
         self.__cb_connected = cb_connected
         self.__cb_disconnected = cb_disconnected
         self.__loop = loop if loop else asyncio.get_event_loop()
@@ -26,6 +28,7 @@ class RPCClient(object):
         self.__client_name = "DobotRPC-WSClient"
         self.__ip = ip
         self.__port = port
+        self.__is_ssl = is_ssl
 
         self.__loop.create_task(self.__connect_recv_worker())
 
@@ -82,7 +85,7 @@ class RPCClient(object):
         rpc_packet = json.dumps(data)
         return rpc_packet
 
-    def __unpack_rpc(self, message: str) -> (int, str, str, str, Exception):
+    def __unpack_rpc(self, message: str):
         try:
             data = json.loads(message)
         except Exception as e:
@@ -106,6 +109,7 @@ class RPCClient(object):
         return rpc_id, method, params, result, error
 
     async def __connect_recv_worker(self):
+        ws_data = None
         while True:
             if self.is_connected:
                 try:
@@ -116,35 +120,43 @@ class RPCClient(object):
                         (str(self.local_address), str(
                             self.remote_address), str(ws_data)))
                 except Exception as e:
-                    loggers.get(LOGGER_NAME).error(e, exc_info=True)
+                    loggers.get(LOGGER_NAME).debug("error:", e)
                     if self.__cb_disconnected:
                         result = self.__cb_disconnected()
                         if isinstance(result, asyncio.Future):
                             await result
 
                 try:
-                    rpc_id, _, _, result, error = self.__unpack_rpc(ws_data)
-                    exchange = self.__exchange_map.get(rpc_id, None)
-                    if exchange:
-                        cb_feedback = exchange["feedback"]
-                        if cb_feedback:
-                            await cb_feedback(error, result)
+                    if ws_data:
+                        rpc_id, _, _, result, error = self.__unpack_rpc(
+                            ws_data)
+                        exchange = self.__exchange_map.get(rpc_id, None)
+                        if exchange:
+                            cb_feedback = exchange["feedback"]
+                            if cb_feedback:
+                                await cb_feedback(error, result)
+                            else:
+                                exchange["result"] = result
+                                exchange["error"] = error
+                                exchange["event"].set()
                         else:
-                            exchange["result"] = result
-                            exchange["error"] = error
-                            exchange["event"].set()
-                    else:
-                        loggers.get(LOGGER_NAME).warning("Invalid request:%s" %
-                                                         str(ws_data))
+                            loggers.get(LOGGER_NAME).warning(
+                                "Invalid request:%s" % str(ws_data))
                 except Exception as e:
-                    loggers.get(LOGGER_NAME).error(e, exc_info=True)
+                    loggers.get(LOGGER_NAME).debug("error", e)
 
             else:
                 try:
-                    self.__ws = await websockets.connect(
-                        "ws://%s:%s" % (self.__ip, self.__port),
-                        timeout=10,
-                    )
+                    if self.__is_ssl:
+                        self.__ws = await websockets.connect(
+                            "wss://%s:%s" % (self.__ip, self.__port),
+                            timeout=10,
+                        )
+                    else:
+                        self.__ws = await websockets.connect(
+                            "ws://%s:%s" % (self.__ip, self.__port),
+                            timeout=10,
+                        )
                     loggers.get(LOGGER_NAME).info("Have connected dobotlink")
                     if self.__cb_connected:
                         result = self.__cb_connected()
